"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const language_service_1 = require("@stylable/language-service");
const vscode_uri_1 = require("vscode-uri");
async function diagnose({ connection, docsDispatcher, stylable, cssService }) {
    let res;
    let ignore = false;
    try {
        res = await connection.workspace.getConfiguration({
            section: 'stylable'
        });
        if (!!res && !!res.diagnostics && !!res.diagnostics.ignore && !!res.diagnostics.ignore.length) {
            ignore = true;
        }
    }
    catch (e) {
        /*Client has no workspace/configuration method, ignore silently */
    }
    const result = [];
    docsDispatcher.keys().forEach(key => {
        const doc = docsDispatcher.get(key);
        if (doc) {
            if (doc.languageId === 'stylable') {
                let diagnostics;
                if (ignore &&
                    res.diagnostics.ignore.some(p => {
                        return vscode_uri_1.URI.parse(doc.uri).fsPath.startsWith(p);
                    })) {
                    diagnostics = [];
                }
                else {
                    diagnostics = language_service_1.createDiagnosis(doc.getText(), vscode_uri_1.URI.parse(doc.uri).fsPath, stylable)
                        .map(diag => {
                        diag.source = 'stylable';
                        return diag;
                    })
                        .concat(cssService.getDiagnostics(doc));
                    result.push(...diagnostics);
                }
                connection.sendDiagnostics({ uri: doc.uri, diagnostics });
            }
        }
    });
    return result;
}
exports.diagnose = diagnose;
//# sourceMappingURL=diagnose.js.map