"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_1 = __importDefault(require("@file-services/node"));
const core_1 = require("@stylable/core");
const vscode_languageserver_1 = require("vscode-languageserver");
const vscode_languageserver_textdocument_1 = require("vscode-languageserver-textdocument");
const capabilities_1 = require("./capabilities");
const vscode_service_1 = require("./vscode-service");
const wrap_fs_1 = require("./wrap-fs");
const connection = vscode_languageserver_1.createConnection(new vscode_languageserver_1.IPCMessageReader(process), new vscode_languageserver_1.IPCMessageWriter(process));
connection.listen();
connection.onInitialize(params => {
    const docs = new vscode_languageserver_1.TextDocuments(vscode_languageserver_textdocument_1.TextDocument);
    const wrappedFs = wrap_fs_1.wrapFs(node_1.default, docs);
    const vscodeStylableLSP = new vscode_service_1.VscodeStylableLanguageService(connection, docs, wrappedFs, new core_1.Stylable(params.rootPath || '', wrappedFs, require));
    docs.listen(connection);
    docs.onDidChangeContent(vscodeStylableLSP.createDiagnosticsHandler());
    docs.onDidClose(vscodeStylableLSP.onDidClose());
    connection.onCompletion(vscodeStylableLSP.onCompletion.bind(vscodeStylableLSP));
    connection.onDefinition(vscodeStylableLSP.onDefinition.bind(vscodeStylableLSP));
    connection.onHover(vscodeStylableLSP.onHover.bind(vscodeStylableLSP));
    connection.onReferences(vscodeStylableLSP.onReferences.bind(vscodeStylableLSP));
    connection.onDocumentColor(vscodeStylableLSP.onDocumentColor.bind(vscodeStylableLSP));
    connection.onColorPresentation(vscodeStylableLSP.onColorPresentation.bind(vscodeStylableLSP));
    connection.onRenameRequest(vscodeStylableLSP.onRenameRequest.bind(vscodeStylableLSP));
    connection.onSignatureHelp(vscodeStylableLSP.onSignatureHelp.bind(vscodeStylableLSP));
    // eslint-disable-next-line @typescript-eslint/no-misused-promises
    connection.onDidChangeConfiguration(vscodeStylableLSP.createDiagnosticsHandler());
    // connection.onDocumentFormatting(stylableLSP.onDocumentFormatting.bind(stylableLSP));
    return capabilities_1.initializeResult;
});
connection.onInitialized(() => {
    // eslint-disable-next-line @typescript-eslint/unbound-method
    connection.client.register(vscode_languageserver_1.DidChangeConfigurationNotification.type, undefined).catch(console.error);
});
//# sourceMappingURL=server.js.map