"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const language_service_1 = require("@stylable/language-service");
const vscode_uri_1 = require("vscode-uri");
const diagnose_1 = require("./diagnose");
class VscodeStylableLanguageService {
    constructor(connection, docs, fs, stylable) {
        this.languageService = new language_service_1.StylableLanguageService({
            fs,
            stylable
        });
        this.textDocuments = docs;
        this.connection = connection;
    }
    onCompletion(params) {
        const { fsPath, doc } = this.getDocAndPath(params.textDocument.uri);
        return doc ? this.languageService.onCompletion(fsPath, doc.offsetAt(params.position)) : [];
    }
    onDefinition(params) {
        const { fsPath, doc } = this.getDocAndPath(params.textDocument.uri);
        return doc ? this.languageService.onDefinition(fsPath, doc.offsetAt(params.position)) : [];
    }
    onHover(params) {
        const { fsPath, doc } = this.getDocAndPath(params.textDocument.uri);
        return doc ? this.languageService.onHover(fsPath, doc.offsetAt(params.position)) : null;
    }
    onReferences(params) {
        const { fsPath, doc } = this.getDocAndPath(params.textDocument.uri);
        return doc ? this.languageService.onReferences(fsPath, doc.offsetAt(params.position)) : [];
    }
    onRenameRequest(params) {
        const { fsPath, doc } = this.getDocAndPath(params.textDocument.uri);
        return doc ? this.languageService.onRenameRequest(fsPath, doc.offsetAt(params.position), params.newName) : {};
    }
    onSignatureHelp(params) {
        const { fsPath, doc } = this.getDocAndPath(params.textDocument.uri);
        return doc ? this.languageService.onSignatureHelp(fsPath, doc.offsetAt(params.position)) : null;
    }
    onDocumentColor(params) {
        const { fsPath } = vscode_uri_1.URI.parse(params.textDocument.uri);
        return this.languageService.onDocumentColor(fsPath);
    }
    onColorPresentation(params) {
        const { fsPath, doc } = this.getDocAndPath(params.textDocument.uri);
        return doc
            ? this.languageService.onColorPresentation(fsPath, { start: doc.offsetAt(params.range.start), end: doc.offsetAt(params.range.end) }, params.color)
            : [];
    }
    createDiagnosticsHandler() {
        const diagnoseConfig = {
            connection: this.connection,
            cssService: this.languageService.cssService,
            docsDispatcher: this.textDocuments,
            stylable: this.languageService.getStylable()
        };
        return () => diagnose_1.diagnose(diagnoseConfig);
    }
    onDidClose() {
        return (event) => {
            this.connection.sendDiagnostics({
                diagnostics: [],
                uri: event.document.uri
            });
        };
    }
    getDocAndPath(uri) {
        const { fsPath } = vscode_uri_1.URI.parse(uri);
        const doc = this.textDocuments.get(uri);
        return { fsPath, doc };
    }
}
exports.VscodeStylableLanguageService = VscodeStylableLanguageService;
//# sourceMappingURL=vscode-service.js.map